# vrt_lss_clustering
VeeRoute.LSS Clustering API

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 3.2.160181
- Package version: 3.2
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import vrt_lss_clustering
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import vrt_lss_clustering
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function

import time
import vrt_lss_clustering
from vrt_lss_clustering.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.veeroute.tech/v3
# See configuration.py for a list of all supported configuration parameters.
configuration = vrt_lss_clustering.Configuration(
    host = "https://api.veeroute.tech/v3"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (JWT): ApiKeyAuth
configuration = vrt_lss_clustering.Configuration(
    access_token = 'YOUR_BEARER_TOKEN'
)


# Enter a context with an instance of the API client
with vrt_lss_clustering.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = vrt_lss_clustering.ClusterApi(api_client)
    cluster_task = vrt_lss_clustering.ClusterTask() # ClusterTask | New clustering request.

    try:
        # Clustering, synchronous call.
        api_response = api_instance.cluster(cluster_task)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ClusterApi->cluster: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *https://api.veeroute.tech/v3*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ClusterApi* | [**cluster**](docs/ClusterApi.md#cluster) | **POST** /clustering/cluster | Clustering, synchronous call.
*ClusterApi* | [**delete_result**](docs/ClusterApi.md#delete_result) | **DELETE** /clustering/result/{id} | Clustering result removal.
*ClusterApi* | [**get_result**](docs/ClusterApi.md#get_result) | **GET** /clustering/result/{id} | Clustering result.
*ClusterApi* | [**run_cluster**](docs/ClusterApi.md#run_cluster) | **POST** /clustering/run_cluster | Clustering process start.
*SystemApi* | [**check**](docs/SystemApi.md#check) | **GET** /clustering/check | Checking the service availability.
*SystemApi* | [**version**](docs/SystemApi.md#version) | **GET** /clustering/version | Getting the service version.
*ValidateApi* | [**validate**](docs/ValidateApi.md#validate) | **POST** /clustering/validate | Data validation for clustering.


## Documentation For Models

 - [CalculationDetail](docs/CalculationDetail.md)
 - [CheckResult](docs/CheckResult.md)
 - [Cluster](docs/Cluster.md)
 - [ClusterAssumptions](docs/ClusterAssumptions.md)
 - [ClusterLimits](docs/ClusterLimits.md)
 - [ClusterPoint](docs/ClusterPoint.md)
 - [ClusterResult](docs/ClusterResult.md)
 - [ClusterSettings](docs/ClusterSettings.md)
 - [ClusterTask](docs/ClusterTask.md)
 - [InlineResponse400](docs/InlineResponse400.md)
 - [InlineResponse401](docs/InlineResponse401.md)
 - [InlineResponse403](docs/InlineResponse403.md)
 - [InlineResponse404](docs/InlineResponse404.md)
 - [InlineResponse415](docs/InlineResponse415.md)
 - [InlineResponse429](docs/InlineResponse429.md)
 - [InlineResponse500](docs/InlineResponse500.md)
 - [InlineResponse501](docs/InlineResponse501.md)
 - [InlineResponse502](docs/InlineResponse502.md)
 - [InlineResponse503](docs/InlineResponse503.md)
 - [InlineResponse504](docs/InlineResponse504.md)
 - [InlineResponseDefault](docs/InlineResponseDefault.md)
 - [Location](docs/Location.md)
 - [Performer](docs/Performer.md)
 - [PlanId](docs/PlanId.md)
 - [PlanInfo](docs/PlanInfo.md)
 - [PlanStatus](docs/PlanStatus.md)
 - [Routing](docs/Routing.md)
 - [RoutingMatrix](docs/RoutingMatrix.md)
 - [TimeWindow](docs/TimeWindow.md)
 - [TraceData](docs/TraceData.md)
 - [TrafficFactor](docs/TrafficFactor.md)
 - [TransportFactor](docs/TransportFactor.md)
 - [TransportType](docs/TransportType.md)
 - [UnclusteredPoint](docs/UnclusteredPoint.md)
 - [ValidateResult](docs/ValidateResult.md)
 - [Validation](docs/Validation.md)
 - [VersionResult](docs/VersionResult.md)
 - [Waypoint](docs/Waypoint.md)


## Documentation For Authorization


## ApiKeyAuth

- **Type**: Bearer authentication (JWT)


## Author

support@veeroute.com


